ReferenceTuple
==============

.. currentmodule:: curies

.. autoclass:: ReferenceTuple
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ReferenceTuple.curie
      ~ReferenceTuple.identifier
      ~ReferenceTuple.prefix

   .. rubric:: Methods Summary

   .. autosummary::

      ~ReferenceTuple.from_curie

   .. rubric:: Attributes Documentation

   .. autoattribute:: curie
   .. autoattribute:: identifier
   .. autoattribute:: prefix

   .. rubric:: Methods Documentation

   .. automethod:: from_curie
